# Residuals

Extract marginal or conditional residuals from a fitted model.
Works with both `CrossedLMEResult` and `statsmodels.MixedLMResults`.

```{eval-rst}
.. autofunction:: interlace.hlm_resid
```
