# Plotting

All plotting functions return `plotnine.ggplot` objects and can be extended with
standard plotnine layers (themes, scales, titles, etc.).

## plot_resid

```{eval-rst}
.. autofunction:: interlace.plot_resid
```

## plot_influence

```{eval-rst}
.. autofunction:: interlace.plot_influence
```

## dotplot_diag

```{eval-rst}
.. autofunction:: interlace.dotplot_diag
```
